@@ -23,7 +23,7 @@
 namespace giac {
 #endif // ndef NO_NAMESPACE_GIAC
 
-#if !defined DOUBLEVAL && (defined __amd64 || defined __x86_64) && !defined SMARTPTR64 
+#if !defined DOUBLEVAL && (defined __amd64 || defined x86_64) && !defined SMARTPTR64 
 #define DOUBLEVAL 1
 #endif
 
@@ -72,6 +72,8 @@ namespace giac {
     _INT___FLOAT_ = _INT_*_DISPATCHBASE+_FLOAT_,
     _INT___VECT = _INT_*_DISPATCHBASE+_VECT,
     _INT___MAP = _INT_*_DISPATCHBASE+_MAP,
+    _INT___REAL = _INT_*_DISPATCHBASE+_REAL,
+    _INT___FRAC = _INT_*_DISPATCHBASE+_FRAC,
     _ZINT__INT_ = _ZINT*_DISPATCHBASE+_INT_,
     _ZINT__ZINT =_ZINT*_DISPATCHBASE+_ZINT,
     _ZINT__CPLX = _ZINT*_DISPATCHBASE+_CPLX,
@@ -82,6 +84,8 @@ namespace giac {
     _ZINT__FLOAT_ = _ZINT*_DISPATCHBASE+_FLOAT_,
     _ZINT__VECT = _ZINT*_DISPATCHBASE+_VECT,
     _ZINT__MAP = _ZINT*_DISPATCHBASE+_MAP,
+    _ZINT__REAL = _ZINT*_DISPATCHBASE+_REAL,
+    _ZINT__FRAC = _ZINT*_DISPATCHBASE+_FRAC,
     _CPLX__INT_ = _CPLX*_DISPATCHBASE+_INT_,
     _CPLX__ZINT = _CPLX*_DISPATCHBASE+_ZINT,
     _CPLX__CPLX = _CPLX*_DISPATCHBASE+_CPLX,
@@ -182,6 +186,8 @@ namespace giac {
     _FRAC__FLOAT_ = _FRAC*_DISPATCHBASE+_FLOAT_,
     _FRAC__DOUBLE_ = _FRAC*_DISPATCHBASE+_DOUBLE_,
     _FRAC__INT_=  _FRAC*_DISPATCHBASE+_INT_,
+    _FRAC_ZINT=  _FRAC*_DISPATCHBASE+_ZINT,
+    _FRAC__REAL=  _FRAC*_DISPATCHBASE+_REAL,
     _SPOL1__SPOL1 = _SPOL1*_DISPATCHBASE+_SPOL1,
     _EXT__EXT = _EXT*_DISPATCHBASE+_EXT,
     _EXT__VECT = _EXT*_DISPATCHBASE+_VECT,
@@ -202,6 +208,7 @@ namespace giac {
     _INT___MOD=  _INT_*_DISPATCHBASE+_MOD,
     _MOD__INT_=  _MOD*_DISPATCHBASE+_INT_,
     _REAL__CPLX = _REAL*_DISPATCHBASE+_CPLX,
+    _REAL__ZINT = _REAL*_DISPATCHBASE+_ZINT,
     _REAL__REAL = _REAL*_DISPATCHBASE+_REAL,
     _REAL__INT_ = _REAL*_DISPATCHBASE+_INT_,
     _REAL__DOUBLE_ = _REAL*_DISPATCHBASE+_DOUBLE_,
@@ -209,6 +216,7 @@ namespace giac {
     _REAL__POLY = _REAL*_DISPATCHBASE+_POLY,
     _REAL__VECT = _REAL*_DISPATCHBASE+_VECT,
     _REAL__MAP = _REAL*_DISPATCHBASE+_MAP,
+    _REAL__FRAC = _REAL*_DISPATCHBASE+_FRAC,
     _USER__USER=  _USER*_DISPATCHBASE+_USER,
     _USER__INT_=  _USER*_DISPATCHBASE+_INT_,
     _USER__POLY=  _USER*_DISPATCHBASE+_POLY
@@ -243,7 +251,9 @@ namespace giac {
     _LOGO__VECT=24,
     _GGB__VECT=25,
     _INTERVAL__VECT=26,
-    _GGBVECT=27
+    _GGBVECT=27,
+    _PRINT__VECT=28,
+    _TUPLE__VECT=29,
   } ;
 
   enum symb_subtypes {
@@ -531,8 +541,24 @@ namespace giac {
     _NEGINT=2*256+2,
     _NONPOSINT=3*256+2,
     _NONNEGINT=4*256+2,
+    _LP_BINARY=106,           //   * binary
+    _LP_BINARYVARIABLES=107,  //   * binaryvariables
+    _LP_DEPTHLIMIT=108,       //   * depthlimit
+    _LP_INTEGER=109,          //   * integer
+    _LP_INTEGERVARIABLES=110, //   * integervariables
+    _LP_MAXIMIZE=111,         //   * maximize
+    _LP_NONNEGATIVE=112,      //   * nonnegative
+    _LP_NONNEGINT=113,        //   * nonnegint
+    _LP_VARIABLES=114,        //   * variables
+    _LP_ASSUME=115,
+    _LP_NODE_LIMIT = 116,             // lp_nodelimit
+    _LP_INTEGER_TOLERANCE = 117,      // lp_integertolerance
+    _LP_METHOD = 118,                 // lp_method
+    _LP_SIMPLEX = 119,                // lp_simplex
+    _LP_INTERIOR_POINT = 120,         // lp_interiorpoint
+    _LP_INITIAL_POINT = 121 ,          // lp_initialpoint
   };
-
+	
   enum mupad_operator {
     _DELETE_OPERATOR=0,
     _PREFIX_OPERATOR=1,
